## Installation

### Install using Pip
Install the package using `pip`:
```
pip install dj-tables
```

### Configuration
Add `dj_tables` to your `INSTALLED_APPS`:
```python
INSTALLED_APPS =(
    # ...
    'dj_tables',
    # ...
)
```

### Running Tests
```
pip install tox
tox
```